/****************************************************************************
** Copyright ( C ) 2011-2012 Nicolas Omont and Artelys.  All rights reserved.
** This file is licensed under the Eclipse Public License.
*****************************************************************************/

set AREAS ordered;
set HOURS ordered;
set TECHNOLOGIES ordered;
param consumption{AREAS, HOURS};

param capacityCost{TECHNOLOGIES};
param energyCost{TECHNOLOGIES};
param hydroEnergy{AREAS};
param maxCapacity{AREAS,TECHNOLOGIES};

var capacity{a in AREAS, t in TECHNOLOGIES} >= 0 <= maxCapacity[a,t];
var energy{a in AREAS, h in HOURS,t in TECHNOLOGIES} >= 0 <= maxCapacity[a ,t];
var exchange{a in AREAS, b in AREAS, h in HOURS : a<>b} >=0 ;

var capacityCosts = sum{a in AREAS, t in TECHNOLOGIES} capacityCost[t]*capacity[a,t];
var energyCosts   = sum{a in AREAS,h in HOURS, t in TECHNOLOGIES} energyCost[t]*energy[a,h,t];

minimize totalCosts : capacityCosts + energyCosts;

subject to capacityCtr{a in AREAS, h in HOURS, t in TECHNOLOGIES } :
	energy[a,h,t] <= capacity[a,t]; 
	
subject to energyCtr{a in AREAS, h in HOURS } :
	sum{t in TECHNOLOGIES} energy[a,h,t] + sum{ b in AREAS : b <> a} exchange[b,a,h] = consumption[a,h] + sum{ b in AREAS : b <> a} exchange[a,b,h];
	
subject to storageCtr{a in AREAS} :
	hydroEnergy[a] >= sum{h in HOURS} energy[a,h,"Hydro"]  ;
	
